package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.CphStuExtraInfo;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 学生其他信息Mapper接口
 *
 * @author srs
 * @date 2024-04-07
 */
public interface CphStuExtraInfoMapper extends BaseMapper<CphStuExtraInfo> {
    /**
     * 查询学生其他信息
     *
     * @param id 学生其他信息主键
     * @return 学生其他信息
     */
    public CphStuExtraInfo selectCphStuExtraInfoById(Long id);

    /**
     * 查询学生其他信息列表
     *
     * @param cphStuExtraInfo 学生其他信息
     * @return 学生其他信息集合
     */
    List<CphStuExtraInfo> selectCphStuExtraInfoList(CphStuExtraInfo cphStuExtraInfo);

    /**
     * 新增学生其他信息
     *
     * @param cphStuExtraInfo 学生其他信息
     * @return 结果
     */
    int insertCphStuExtraInfo(CphStuExtraInfo cphStuExtraInfo);

    /**
     * 修改学生其他信息
     *
     * @param cphStuExtraInfo 学生其他信息
     * @return 结果
     */
    int updateCphStuExtraInfo(CphStuExtraInfo cphStuExtraInfo);

    /**
     * 删除学生其他信息
     *
     * @param id 学生其他信息主键
     * @return 结果
     */
    int deleteCphStuExtraInfoById(Long id);

    /**
     * 批量删除学生其他信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCphStuExtraInfoByIds(Long[] ids);
}
