package com.srs.web.controller.comprehensive;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.comprehensive.domain.CphStuExtraInfo;
import com.srs.comprehensive.service.ICphStuExtraInfoService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 学生其他信息Controller
 *
 * @author srs
 * @date 2024-04-07
 */
@RestController
@RequestMapping("/comprehensive/extraInfo")
@Api(value = "学生其他信息管理", tags = "学生其他信息管理")
public class CphStuExtraInfoController extends BaseController {
    @Autowired
    private ICphStuExtraInfoService cphStuExtraInfoService;


    @GetMapping("/getOwnInfo")
    @ApiOperation("查询学生自己的其他信息")
    public AjaxResult getOwnInfo(){
        CphStuExtraInfo res = cphStuExtraInfoService.getStuInfo(getUsername());
        return  AjaxResult.success(res);
    }

    /**
     * 跟据学生学号查询学生其他信息
     * @return
     */
    @GetMapping("/getOwnInfoByStuNo")
    @ApiOperation("查询学生自己的其他信息")
    public AjaxResult getOwnInfo(@RequestParam String stuNo){
        CphStuExtraInfo res = cphStuExtraInfoService.getStuInfo(stuNo);
        return  AjaxResult.success(res);
    }

    @PostMapping("/submitOwnInfo")
    @ApiOperation("提交学生自己的其他信息")
    public AjaxResult submitOwnInfo(@RequestBody CphStuExtraInfo param){
        param.setStuNo(getUsername());
        return cphStuExtraInfoService.submitOwnInfo(param);
    }


    /**
     * 查询学生其他信息列表
     */
    @PreAuthorize("@ss.hasPermi('comprehensive:extraInfo:list')")
    @GetMapping("/list")
    @ApiOperation("查询学生其他信息列表")
    public TableDataInfo list(CphStuExtraInfo cphStuExtraInfo) {
        startPage();
        List<CphStuExtraInfo> list = cphStuExtraInfoService.selectCphStuExtraInfoList(cphStuExtraInfo);
        return getDataTable(list);
    }

    /**
     * 导出学生其他信息列表
     */
    @PreAuthorize("@ss.hasPermi('comprehensive:extraInfo:export')")
    @Log(title = "学生其他信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出学生其他信息列表")
    public void export(HttpServletResponse response, CphStuExtraInfo cphStuExtraInfo) {
        List<CphStuExtraInfo> list = cphStuExtraInfoService.selectCphStuExtraInfoList(cphStuExtraInfo);
        ExcelUtil<CphStuExtraInfo> util = new ExcelUtil<CphStuExtraInfo>(CphStuExtraInfo.class);
        util.exportExcel(response, list, "学生其他信息数据");
    }

    /**
     * 获取学生其他信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('comprehensive:extraInfo:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取学生其他信息详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(cphStuExtraInfoService.selectCphStuExtraInfoById(id));
    }

    /**
     * 新增学生其他信息
     */
    @PreAuthorize("@ss.hasPermi('comprehensive:extraInfo:add')")
    @Log(title = "学生其他信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增学生其他信息")
    public AjaxResult add(@RequestBody CphStuExtraInfo cphStuExtraInfo) {
        return toAjax(cphStuExtraInfoService.insertCphStuExtraInfo(cphStuExtraInfo));
    }

    /**
     * 修改学生其他信息
     */
    @PreAuthorize("@ss.hasPermi('comprehensive:extraInfo:edit')")
    @Log(title = "学生其他信息", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改学生其他信息")
    public AjaxResult edit(@RequestBody CphStuExtraInfo cphStuExtraInfo) {
        return toAjax(cphStuExtraInfoService.updateCphStuExtraInfo(cphStuExtraInfo));
    }

    /**
     * 删除学生其他信息
     */
    @PreAuthorize("@ss.hasPermi('comprehensive:extraInfo:remove')")
    @Log(title = "学生其他信息", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除学生其他信息")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(cphStuExtraInfoService.deleteCphStuExtraInfoByIds(ids));
    }
}
